/*
 * rprintmsg.c   remote printing version of "printmsg.c"
 */
 
#include <stdio.h>
#include <rpc/rpc.h>        /* always needed */
#include "msg.h"            /* msg.h wil be generated by rpcgen */

main(int argc, char *argv[])
{
    CLIENT *cl;
    int *result;
    char *server;
    char *message;
    
    if (argc != 3) {
        fprintf(stderr,
        "usage %s host message\n",argv[0]);
    }    
    server = argv[1];
    message = argv[2];
    
    /* Creare client handle for calling MESSAGEPROG on the server
     * designated on the command line.  We tell the RPC package
     * to use the tcp protocol when contacting the server.
     */    
    cl = clnt_create(server, MESSAGEPROG, MESSAGEVERS, "tcp");
    if (cl == NULL) {
        /*
         * Couldn't establish connection with server.
         * Print error message and die.
         */
        clnt_pcreateerror(server);
        exit(1);
    }
    
    /* 
     * Call the remote procedure "printmessage" on the server.
     */     
    result = printmessage_1(&message, cl);
    if (result == NULL) {
        /*
         * An error occurred while calling the server.
         * Print error message and die
         */
        clnt_perror(cl, server);
        exit(1);
    }
    /*
     * Okay, we successfully called the remote procedure
     */
    if (*result == 0) {
        /*
         * Server was unable to print our message.
         * Print error message and die.
         */
        fprintf(stderr, "%s: %s couldn't print your message\n",
        argv[0], server);
        exit(1);
    }
    /*
     * Message got printed at server
     */
     printf("Message delivered to %s!\n", server);
     exit(0);
}
